# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/dreamai_pdf',
                'doc_host': 'https://HamzaFarhan.github.io',
                'git_url': 'https://github.com/HamzaFarhan/dreamai_pdf',
                'lib_path': 'dreamai_pdf'},
  'syms': { 'dreamai_pdf.core': { 'dreamai_pdf.core.cid_to_char': ('core.html#cid_to_char', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.extract_text': ('core.html#extract_text', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.extract_text_dict': ('core.html#extract_text_dict', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.extract_text_list': ('core.html#extract_text_list', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.process_line': ('core.html#process_line', 'dreamai_pdf/core.py'),
                                  'dreamai_pdf.core.process_text': ('core.html#process_text', 'dreamai_pdf/core.py')},
            'dreamai_pdf.extract': { 'dreamai_pdf.extract.load_ems_model': ('extract.html#load_ems_model', 'dreamai_pdf/extract.py'),
                                     'dreamai_pdf.extract.load_segs_model': ('extract.html#load_segs_model', 'dreamai_pdf/extract.py'),
                                     'dreamai_pdf.extract.print_segments': ('extract.html#print_segments', 'dreamai_pdf/extract.py'),
                                     'dreamai_pdf.extract.text_to_segments': ('extract.html#text_to_segments', 'dreamai_pdf/extract.py'),
                                     'dreamai_pdf.extract.write_embeddings': ('extract.html#write_embeddings', 'dreamai_pdf/extract.py'),
                                     'dreamai_pdf.extract.write_segments': ('extract.html#write_segments', 'dreamai_pdf/extract.py')},
            'dreamai_pdf.imports': {},
            'dreamai_pdf.ner': { 'dreamai_pdf.ner.edu_ner': ('ner.html#edu_ner', 'dreamai_pdf/ner.py'),
                                 'dreamai_pdf.ner.is_valid_jner': ('ner.html#is_valid_jner', 'dreamai_pdf/ner.py'),
                                 'dreamai_pdf.ner.is_valid_tner': ('ner.html#is_valid_tner', 'dreamai_pdf/ner.py'),
                                 'dreamai_pdf.ner.job_ner': ('ner.html#job_ner', 'dreamai_pdf/ner.py'),
                                 'dreamai_pdf.ner.load_job_model': ('ner.html#load_job_model', 'dreamai_pdf/ner.py'),
                                 'dreamai_pdf.ner.load_ner_model': ('ner.html#load_ner_model', 'dreamai_pdf/ner.py'),
                                 'dreamai_pdf.ner.proc_ner': ('ner.html#proc_ner', 'dreamai_pdf/ner.py'),
                                 'dreamai_pdf.ner.work_ner': ('ner.html#work_ner', 'dreamai_pdf/ner.py')}}}
